@@ -1,6 +1,7 @@
-covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NULL, covFix=NULL, 
+covariateModelSelection <- function(pen.coef=NULL, weight=1, n.full=10,
+                                    nb.model=1, covToTransform=NULL, covFix=NULL, 
                                     direction="both", paramToUse="all", steps=1000, p.max=1, 
-                                    sp0=NULL, iter=1, correlation.model=NULL) {
+                                    sp0=NULL, iter=1, correlation.model=NULL, eta=NULL) {
   
   # correlation.model=NULL
   #  project.folder <- mlx.getProjectSettings()$directory
@@ -76,7 +77,10 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
         yj <- qnorm(yj)
         names(yj) <- paste0("probit.",nj)
       } 
-      
+      if (!is.null(eta))
+        etaj <- eta[paste0("eta_",nj)]
+      else
+        etaj <- NULL
       if (length(covFix)>0) {
         cmj <- cov.model[[nj]][covFix]
         cov0 <- names(which(!cmj))
@@ -85,9 +89,14 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
         cov0 <- cov1 <- NULL
       }
       #      cov0 <- cov1 <- NULL
-      #     browser()
+      #      browser()
       
-      r[[j]] <- lm.all(yj, covariates, tcov.names, pen.coef=pen.coef, nb.model=nb.model, 
+      # if (identical(weight,1))
+      #   pwj <- 1
+      # else
+      pwj <- weight[nj,]
+      
+      r[[j]] <- lm.all(nj, yj, etaj, covariates, tcov.names, pen.coef=pen.coef, nb.model=nb.model, pw=pwj, n.full=n.full,
                        direction=direction, steps=steps, p.max=p.max, cov0=cov0, cov1=cov1, iter=iter)
       res[[j]] <- r[[j]]$res
       r.cov0[[j]] <- r[[j]]$cov0
@@ -113,7 +122,7 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
   
   if (length(correlation.model) >0 ) {
     #    en <- as.data.frame(scale(e))
-
+    
     for (ic in (1:length(correlation.model))) {
       pic <- correlation.model[[ic]]
       if (all(pic %in% e.names)) {
@@ -121,7 +130,9 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
         epic <- e[,ipic]
         gic <- solve(cov(epic))
         jic <- match(pic, names(ind.dist))
+        
         #   print(head(epic))
+  #      if (1>2){
         for (itk in 1:2) {
           jk <- 0
           for (j in jic) {
@@ -129,6 +140,7 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
             dj <- ind.dist[j]
             nj <- names(dj)
             yj <- sp.df[nj]
+            pwj <- weight[nj,]
             if (tolower(dj) == "lognormal") {
               yj <- log(yj)
               names(yj) <- paste0("log.",nj)
@@ -139,6 +151,11 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
               yj[[1]] <- qnorm(yj[[1]])
               names(yj) <- paste0("probit.",nj)
             } 
+            if (!is.null(eta))
+              etaj <- eta[paste0("eta_",nj)]
+            else
+              etaj <- NULL
+            
             if (length(covFix)>0) {
               cmj <- cov.model[[nj]][covFix]
               cov0 <- names(which(!cmj))
@@ -149,7 +166,7 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
             ejc <- as.matrix(epic[,-jk])%*%matrix(gic[jk, -jk], ncol=1)/gic[jk, jk]
             yjc <- yj + ejc
             
-            r[[j]] <- lm.all(yjc, covariates, tcov.names, pen.coef=pen.coef, nb.model=nb.model, 
+            r[[j]] <- lm.all(nj, yjc, etaj, covariates, tcov.names, pen.coef=pen.coef, nb.model=nb.model, pw=pwj, n.full=n.full,
                              direction=direction, steps=steps, p.max=p.max, cov0=cov0, cov1=cov1, iter=iter)
             res[[j]] <- r[[j]]$res
             r.cov0[[j]] <- r[[j]]$cov0
@@ -172,6 +189,8 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
   tr0 <- NULL
   for (k in (1:n.param)) {
     if (!identical(res[[k]],"none")) {
+      # if (nrow(res[[k]]) < nb.model)
+      #   res[[k]][(nrow(res[[k]])+1):nb.model, ] <- res[[k]][nrow(res[[k]]), ] 
       covariate.model[[k]][1:length(covariate.model[[k]])] <- FALSE
       if (indvar[k]) {
         ck <- attr(r[[k]]$model$terms,"term.labels")
@@ -204,14 +223,14 @@ covariateModelSelection <- function(pen.coef=NULL, nb.model=1, covToTransform=NU
 
 #-----------------------------------
 
-lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
-                   direction='both',steps = 1000, p.max=1, cov0=NULL, cov1=NULL, iter=1) {
+lm.all <- function(ny, y, eta, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL, pw=NULL, n.full=10,
+                   direction='both', steps = 1000, p.max=1, cov0=NULL, cov1=NULL, iter=1) {
   
   N <- length(unique(x$id))
   nrep <- nrow(y)/N
   if (p.max<=1) {
     nx <- setdiff(names(x), c("id","rep"))
-    yc <- rowMeans(matrix(y[[1]], ncol=nrep))
+    yc <- rowMeans(matrix(y[[1]], nrow=N))
     #    yc=colMeans(matrix(y[[1]], ncol=N))
     xc <- x
     # xc <- x[order(x$id),,drop=FALSE]
@@ -221,17 +240,42 @@ lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
     pjc <- NULL
     for (nc in nxc) {
       lmc <- lm(yc ~ xc[[nc]])
-      pjc <- c(pjc, signif(anova(lm0, lmc)$`Pr(>F)`[2],4))
+      pc <- signif(anova(lm0, lmc)$`Pr(>F)`[2],4)
+      pjc <- c(pjc, pc)
+      # rc <- exp(pen.coef*(pw[nc]-1)/2)
+      # pjc <- c(pjc, pc*rc/(1 - pc + pc*rc))
+    }
+    pjc <- p.weight(pjc, pw[nxc], pen.coef)
+    names(pjc) <- nxc
+    if (!is.null(eta)) {
+      etac <- rowMeans(matrix(eta[[1]], nrow=N))
+      lm0 <- lm(etac ~1)
+      pjec <- NULL
+      for (nc in nxc) {
+#        if (length(etac) != length(xc[[nc]]))  browser()
+        lmc <- lm(etac ~ xc[[nc]])
+        pc <- signif(anova(lm0, lmc)$`Pr(>F)`[2],4)
+        pjec <- c(pjec, pc)
+        # rc <- exp(pen.coef*(pw[nc]-1)/2)
+        # pjc <- c(pjc, pc*rc/(1 - pc + pc*rc))
+      }
+      pjec <- p.weight(pjec, pw[nxc], pen.coef)
+      names(pjec) <- nxc
+      # print(names(y))
+      # print(rbind(pjc, pjec))
+      pjc <- pmin(pjc, pjec, na.rm=T)
+ #     if (names(y) %in% c("log.Cl", "log.V1")) pjc[1] <- 0
     }
     # if (length(which(pjc<p.max)) == 0)
     #   list.c <- which(pjc<max(pjc))
     # else
     #   pjc <- p.adjust(pjc, method="BH")
+    pjc[names(which(mlx.getIndividualParameterModel()$covariateModel[[ny]]))] <- 0
     list.c <- which(pjc>p.max)
     # browser()
     
     cov0 <- c(cov0, nxc[list.c])
-    direction <- ifelse(length(setdiff(nx, cov0))<=10,"full",direction)
+    direction <- ifelse(length(setdiff(nx, cov0))<=n.full,"full",direction)
     # x <- x[, -which(names(x) %in% nx[list.c])]
   } else
     list.c <- NULL
@@ -288,12 +332,20 @@ lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
       
       
       if(direction=='backward'){
-        lm.sat=stepAIC(model.sature, direction='backward', trace = FALSE, k=nrep*pen.coef,
-                       scope=list(upper=model.sature, lower=model.cst), steps=steps)
+        lm.sat=mlx.stepAIC(model.sature, direction='backward', trace = FALSE, k=nrep*pen.coef,
+                           scope=list(upper=model.sature, lower=model.cst), steps=steps, weight=pw)
       }
       else {
-        lm.cst=stepAIC(model.cst, direction=direction, trace = FALSE, k=nrep*pen.coef,
-                       scope=list(upper=model.sature, lower=model.cst), steps=steps)
+ #       lm.cst=mlx.stepAIC(model.cst, direction=direction, trace = FALSE, k=nrep*pen.coef,
+ #                          scope=list(upper=model.sature, lower=model.cst), steps=steps, weight=pw)
+        c.cur <- names(which(mlx.getIndividualParameterModel()$covariateModel[[ny]]))
+        f.cur <- "y ~ 1"
+        if (length(c.cur)>0)
+          f.cur <- paste0(f.cur, "+", paste(c.cur,collapse="+"))
+        f.cur <- as.formula(f.cur)
+        model.cur=lm(f.cur,l_data)
+        lm.cst=stepAIC(model.cur, direction=direction, trace=FALSE, k=nrep*pen.coef,
+                           scope=list(upper=model.sature, lower=model.cst), steps=steps)
       }
     }
     , error=function(e) {
@@ -303,20 +355,21 @@ lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
     ## after tryCatch
     # Which covariates are used (written in 1-row data frame G)
     Gnames = names(x)
-    G <- data.frame(matrix(ncol = length(Gnames), nrow = 1))
+    G <- data.frame(matrix(0, ncol = length(Gnames), nrow = 1))
     colnames(G) <- Gnames
     
     # exact used covariates (with original names of cats), fill in G
-    usedcovariates = names(llk$model)[-1] #names(coef(llk)) 
-    for (i in names(G)){
-      if (i %in% usedcovariates ) G[1,i]=1 else G[1,i]=0
-      if (paste0('log.',i) %in% usedcovariates ) G[1,i]=G[1,i]+2  
-      # = 3 if both log and non-log are used
-    }
+    usedcovariates = names(llk$model)[-1] #names(coef(llk)) 1, ]
+    G[1, usedcovariates] <- 1
+    # for (i in names(G)){
+    #   if (i %in% usedcovariates ) G[1,i]=1 else G[1,i]=0
+    #  if (paste0('log.',i) %in% usedcovariates ) G[1,i]=G[1,i]+2  
+    # = 3 if both log and non-log are used
+    #}
     
     ll = logLik(llk)/nrep
     df = length(coef(llk))-1 # except Intercept
-    criterion = -2*ll + df*pen.coef
+    criterion = -2*ll + pen.coef*sum(pw[usedcovariates])
     
     res <- data.frame(ll=round(ll,digits=3), df=df,  criterion=round(criterion,digits=3))
     j0.num <- j0.num[!(names(j0.num) %in% tr.names)]
@@ -328,7 +381,10 @@ lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
     }
     res <- cbind(G==1, res)
     #  res <- cbind(G, res)
+    if (nb.model==1)
     res[,c("ll","df","criterion")] <- NULL
+    else
+      res[2:nb.model,] <- res[1,]
     row.names(res) <- 1:nrow(res)
     
     #  browser()
@@ -396,6 +452,7 @@ lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
   for (k in 1:ng) {
     xk <- data.frame(y=yg)
     Gk <- G[k,,drop=FALSE]
+    pwk <- pw[names(Gk)]
     j1 <- which(Gk==1)
     if (length(j1)>0)
       xk[names(x)[j1]] <- xg[j1]
@@ -409,16 +466,18 @@ lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
       , error=function(e) {
         return(-Inf)        }      
     )    
-    #dfk <- sum(Gk>0)
-    dfk <- lmk$rank
-    bick <- -2*llk + pen.coef*dfk + any(Gk==2)*0.001
+    dfk <- sum(Gk>0)
+    # dfk <- lmk$rank
+    # pen.covk <- 2*(sum(Gk*log((1-prior)/0.5)) + sum((1-Gk)*log(prior/0.5)))
+    # bick <- -2*llk + pen.coef*dfk + pen.covk
+    
+    bick <- -2*llk + pen.coef*sum(Gk*pwk)
     ll <- c(ll , llk)
     df <- c(df, dfk)
     bic <- c(bic , bick)
     #  bic.cor <- c(bic.cor , bick-corb*dfk)
     bic.cor <- c(bic.cor , bick)
   }
-  
   bic <- round(bic.cor, digits=3)
   i0 <- rep(1,ng)
   mG <- ncol(G)
@@ -485,3 +544,210 @@ lm.all <- function(y, x, tr.names=NULL, pen.coef=NULL, nb.model=NULL,
   
   return(list(model=lm.min, res=res, cov0=cov0))
 }
+
+#######################################################
+
+mlx.stepAIC<-function (object, scope, scale = 0, direction = c("both", "backward","forward"), 
+                       trace = 1, keep = NULL, steps = 1000, use.start = FALSE, k = 2, weight=NULL) 
+{
+  mydeviance <- function(x) {
+    dev <- deviance(x)
+    if (!is.null(dev)) 
+      dev
+    else extractAIC(x, k = 0)[2L]
+  }
+  cut.string <- function(string) {
+    if (length(string) > 1L) 
+      string[-1L] <- paste("\n", string[-1L], sep = "")
+    string
+  }
+  re.arrange <- function(keep) {
+    namr <- names(k1 <- keep[[1L]])
+    namc <- names(keep)
+    nc <- length(keep)
+    nr <- length(k1)
+    array(unlist(keep, recursive = FALSE), c(nr, nc), list(namr, namc))
+  }
+  step.results <- function(models, fit, object, usingCp = FALSE) {
+    change <- sapply(models, "[[", "change")
+    rd <- sapply(models, "[[", "deviance")
+    dd <- c(NA, abs(diff(rd)))
+    rdf <- sapply(models, "[[", "df.resid")
+    ddf <- c(NA, abs(diff(rdf)))
+    AIC <- sapply(models, "[[", "AIC")
+    heading <- c("Stepwise Model Path \nAnalysis of Deviance Table", 
+                 "\nInitial Model:", deparse(formula(object)), "\nFinal Model:", 
+                 deparse(formula(fit)), "\n")
+    aod <- if (usingCp) 
+      data.frame(Step = change, Df = ddf, Deviance = dd, 
+                 `Resid. Df` = rdf, `Resid. Dev` = rd, Cp = AIC, 
+                 check.names = FALSE)
+    else data.frame(Step = change, Df = ddf, Deviance = dd, 
+                    `Resid. Df` = rdf, `Resid. Dev` = rd, AIC = AIC, 
+                    check.names = FALSE)
+    attr(aod, "heading") <- heading
+    class(aod) <- c("Anova", "data.frame")
+    fit$anova <- aod
+    fit
+  }
+  extractAIC.getpenalisationweight<-function(object, weight, k){
+    variableyn<-weight
+    variableyn[]<-0
+    variableyn[attr(terms(object),"term.labels")]<-1
+    penalweight<- sum(variableyn*(weight-1)*k)
+    penalweight
+  }
+  
+  extractAIC.updateAICweight<-function(object,objaod,weight,k,drop=TRUE){
+    objaod[,"AIC"]<-objaod[,"AIC"] + extractAIC.getpenalisationweight(object,weight,k)
+    no <- rownames(objaod)[2:dim(objaod)[1]]
+    if (drop)
+      objaod[no,"AIC"] <- objaod[no,"AIC"] - (weight[no]-1)*k
+    else
+      objaod[no,"AIC"] <- objaod[no,"AIC"] + (weight[no]-1)*k
+    objaod
+  }
+  
+  Terms <- terms(object)
+  object$formula <- Terms
+  if (inherits(object, "lme")) 
+    object$call$fixed <- Terms
+  else if (inherits(object, "gls")) 
+    object$call$model <- Terms
+  else object$call$formula <- Terms
+  if (use.start) 
+    warning("'use.start' cannot be used with R's version of 'glm'")
+  md <- missing(direction)
+  direction <- match.arg(direction)
+  backward <- direction == "both" | direction == "backward"
+  forward <- direction == "both" | direction == "forward"
+  if (missing(scope)) {
+    fdrop <- numeric()
+    fadd <- attr(Terms, "factors")
+    if (md) 
+      forward <- FALSE
+  }
+  else {
+    if (is.list(scope)) {
+      fdrop <- if (!is.null(fdrop <- scope$lower)) 
+        attr(terms(update.formula(object, fdrop)), "factors")
+      else numeric()
+      fadd <- if (!is.null(fadd <- scope$upper)) 
+        attr(terms(update.formula(object, fadd)), "factors")
+    }
+    else {
+      fadd <- if (!is.null(fadd <- scope)) 
+        attr(terms(update.formula(object, scope)), "factors")
+      fdrop <- numeric()
+    }
+  }
+  models <- vector("list", steps)
+  if (!is.null(keep)) 
+    keep.list <- vector("list", steps)
+  n <- nobs(object, use.fallback = TRUE)
+  fit <- object
+  bAIC <- extractAIC(fit, scale, k = k)  #Was +...
+  edf <- bAIC[1L]
+  bAIC <- bAIC[2L]+extractAIC.getpenalisationweight(fit,weight,k)
+  if (is.na(bAIC)) 
+    stop("AIC is not defined for this model, so 'stepAIC' cannot proceed")
+  if (bAIC == -Inf) 
+    stop("AIC is -infinity for this model, so 'stepAIC' cannot proceed")
+  nm <- 1
+  Terms <- terms(fit)
+  if (trace) {
+    cat("Start:  AIC=", format(round(bAIC, 2)), "\n", cut.string(deparse(formula(fit))), 
+        "\n\n", sep = "")
+    utils::flush.console()
+  }
+  models[[nm]] <- list(deviance = mydeviance(fit), df.resid = n - 
+                         edf, change = "", AIC = bAIC)
+  if (!is.null(keep)) 
+    keep.list[[nm]] <- keep(fit, bAIC)
+  usingCp <- FALSE
+  while (steps > 0) {
+    steps <- steps - 1
+    AIC <- bAIC
+    ffac <- attr(Terms, "factors")
+    if (!is.null(sp <- attr(Terms, "specials")) && !is.null(st <- sp$strata)) 
+      ffac <- ffac[-st, ]
+    scope <- factor.scope(ffac, list(add = fadd, drop = fdrop))
+    aod <- NULL
+    change <- NULL
+    if (backward && length(scope$drop)) {
+      aod <- dropterm(fit, scope$drop, scale = scale, trace = max(0, trace - 1), k = k)#Was +...
+      aod<-extractAIC.updateAICweight(fit,aod,weight,k,drop=TRUE)
+      rn <- row.names(aod)
+      row.names(aod) <- c(rn[1L], paste("-", rn[-1L], sep = " "))
+      if (any(aod$Df == 0, na.rm = TRUE)) {
+        zdf <- aod$Df == 0 & !is.na(aod$Df)
+        nc <- match(c("Cp", "AIC"), names(aod))
+        nc <- nc[!is.na(nc)][1L]
+        ch <- abs(aod[zdf, nc] - aod[1, nc]) > 0.01
+        if (any(is.finite(ch) & ch)) {
+          warning("0 df terms are changing AIC")
+          zdf <- zdf[!ch]
+        }
+        if (length(zdf) > 0L) 
+          change <- rev(rownames(aod)[zdf])[1L]
+      }
+    }
+    if (is.null(change)) {
+      if (forward && length(scope$add)) {
+        aodf <- addterm(fit, scope$add, scale = scale, trace = max(0, trace - 1), k = k)#Was +...
+        aodf<-extractAIC.updateAICweight(fit, aodf, weight, k, drop=FALSE)
+        rn <- row.names(aodf)
+        row.names(aodf) <- c(rn[1L], paste("+", rn[-1L], 
+                                           sep = " "))
+        aod <- if (is.null(aod)) 
+          aodf
+        else rbind(aod, aodf[-1, , drop = FALSE])
+      }
+      attr(aod, "heading") <- NULL
+      if (is.null(aod) || ncol(aod) == 0) 
+        break
+      nzdf <- if (!is.null(aod$Df)) 
+        aod$Df != 0 | is.na(aod$Df)
+      aod <- aod[nzdf, ]
+      if (is.null(aod) || ncol(aod) == 0) 
+        break
+      nc <- match(c("Cp", "AIC"), names(aod))
+      nc <- nc[!is.na(nc)][1L]
+      o <- order(aod[, nc])
+      if (trace) {
+        print(aod[o, ])
+        utils::flush.console()
+      }
+      if (o[1L] == 1) 
+        break
+      change <- rownames(aod)[o[1L]]
+    }
+    usingCp <- match("Cp", names(aod), 0) > 0
+    fit <- update(fit, paste("~ .", change), evaluate = FALSE)
+    fit <- eval.parent(fit)
+    nnew <- nobs(fit, use.fallback = TRUE)
+    if (all(is.finite(c(n, nnew))) && nnew != n) 
+      stop("number of rows in use has changed: remove missing values?")
+    Terms <- terms(fit)
+    bAIC <- extractAIC(fit, scale, k = k)#Was +...
+    edf <- bAIC[1L]
+    bAIC <- bAIC[2L]+extractAIC.getpenalisationweight(fit,weight,k)
+    if (trace) {
+      cat("\nStep:  AIC=", format(round(bAIC, 2)), "\n", 
+          cut.string(deparse(formula(fit))), "\n\n", sep = "")
+      utils::flush.console()
+    }
+    if (bAIC >= AIC + 1e-07) 
+      break
+    nm <- nm + 1
+    models[[nm]] <- list(deviance = mydeviance(fit), df.resid = n - 
+                           edf, change = change, AIC = bAIC)
+    if (!is.null(keep)) 
+      keep.list[[nm]] <- keep(fit, bAIC)
+  }
+  if (!is.null(keep)) 
+    fit$keep <- re.arrange(keep.list[seq(nm)])
+  step.results(models = models[seq(nm)], fit, object, usingCp)
+}
+
+
